@@ -7,7 +7,7 @@
 #endif
 {-|
 Module:      TextShow.Classes
-Copyright:   (C) 2014-2016 Ryan Scott
+Copyright:   (C) 2014-2017 Ryan Scott
 License:     BSD-style (see the file LICENSE)
 Maintainer:  Ryan Scott
 Stability:   Provisional
@@ -186,6 +186,12 @@ showbParen :: Bool -> Builder -> Builder
 showbParen p builder | p         = singleton '(' <> builder <> singleton ')'
                      | otherwise = builder
 
+-- | Construct a 'Builder' containing a comma followed by a space.
+--
+-- /Since: 3.6/
+showbCommaSpace :: Builder
+showbCommaSpace = ", "
+
 -- | Construct a 'Builder' containing a single space character.
 --
 -- /Since: 2/
@@ -214,6 +220,12 @@ showtParen :: Bool -> TS.Text -> TS.Text
 showtParen p t | p         = TS.singleton '(' <> t <> TS.singleton ')'
                | otherwise = t
 
+-- | Construct a strict 'TS.Text' containing a comma followed by a space.
+--
+-- /Since: 3.6/
+showtCommaSpace :: TS.Text
+showtCommaSpace = ", "
+
 -- | Construct a strict 'TS.Text' containing a single space character.
 --
 -- /Since: 3.4/
@@ -240,6 +252,12 @@ showtlParen p t | p         = TL.singleton '(' <> t <> TL.singleton ')'
                 | otherwise = t
 {-# INLINE showtlParen #-}
 
+-- | Construct a lazy 'TL.Text' containing a comma followed by a space.
+--
+-- /Since: 3.6/
+showtlCommaSpace :: TL.Text
+showtlCommaSpace = ", "
+
 -- | Construct a lazy 'TL.Text' containing a single space character.
 --
 -- /Since: 3.4/
