@@ -1,16 +1,15 @@
-{-# LANGUAGE CPP               #-}
 {-# LANGUAGE OverloadedStrings #-}
 {-# LANGUAGE TemplateHaskell   #-}
 {-# OPTIONS_GHC -fno-warn-orphans #-}
 {-|
 Module:      TextShow.Data.Char
-Copyright:   (C) 2014-2016 Ryan Scott
+Copyright:   (C) 2014-2017 Ryan Scott
 License:     BSD-style (see the file LICENSE)
 Maintainer:  Ryan Scott
 Stability:   Provisional
 Portability: GHC
 
-Monomorphic 'TextShow' functions for 'Char' and 'String'.
+'TextShow' instances and monomorphic functions for 'Char' and 'String'.
 
 /Since: 2/
 -}
@@ -32,11 +31,9 @@ import           Prelude ()
 import           Prelude.Compat
 
 import           TextShow.Classes (TextShow(..))
-import           TextShow.Data.Integral (showbIntPrec)
+import           TextShow.Data.Integral ()
 import           TextShow.TH.Internal (deriveTextShow)
 
-#include "inline.h"
-
 -- | A table of ASCII control characters that needs to be escaped with a backslash.
 --
 -- /Since: 2/
@@ -59,7 +56,7 @@ showbChar c    = singleton '\'' <> showbLitChar c <> singleton '\''
 --
 -- /Since: 2/
 showbLitChar :: Char -> Builder
-showbLitChar c | c > '\DEL' = singleton '\\' <> showbIntPrec 0 (ord c)
+showbLitChar c | c > '\DEL' = singleton '\\' <> showb (ord c)
 showbLitChar '\DEL'         = "\\DEL"
 showbLitChar '\\'           = "\\\\"
 showbLitChar c | c >= ' '   = singleton c
@@ -88,8 +85,8 @@ showbLitString []             = mempty
 showbLitString ('\SO':'H':cs) = "\\SO\\&H" <> showbLitString cs
 showbLitString ('"':cs)       = "\\\"" <> showbLitString cs
 showbLitString (c:d:cs)
-    | c > '\DEL' && isDigit d = singleton '\\' <> showbIntPrec 0 (ord c) <> "\\&"
-                             <> singleton d <> showbLitString cs
+    | c > '\DEL' && isDigit d = singleton '\\' <> showb (ord c) <> "\\&"
+                             <> singleton d    <> showbLitString cs
 showbLitString (c:cs)         = showbLitChar c <> showbLitString cs
 
 -- | Convert a 'GeneralCategory' to a 'Builder'.
@@ -99,11 +96,13 @@ showbGeneralCategory :: GeneralCategory -> Builder
 showbGeneralCategory = showb
 {-# INLINE showbGeneralCategory #-}
 
+-- | /Since: 2/
 instance TextShow Char where
     showb = showbChar
-    INLINE_INST_FUN(showb)
+    {-# INLINE showb #-}
 
     showbList = showbString
-    INLINE_INST_FUN(showbList)
+    {-# INLINE showbList #-}
 
+-- | /Since: 2/
 $(deriveTextShow ''GeneralCategory)
