@@ -2,13 +2,13 @@
 {-# OPTIONS_GHC -fno-warn-orphans #-}
 {-|
 Module:      TextShow.Data.Fixed
-Copyright:   (C) 2014-2016 Ryan Scott
+Copyright:   (C) 2014-2017 Ryan Scott
 License:     BSD-style (see the file LICENSE)
 Maintainer:  Ryan Scott
 Stability:   Provisional
 Portability: GHC
 
-Monomorphic 'Show' function for 'Fixed' values.
+Provides 'TextShow' instance for 'Fixed', as well as the 'showbFixed' function.
 
 /Since: 2/
 -}
@@ -36,8 +36,6 @@ import Data.Fixed (Fixed, showFixed)
 import Data.Text.Lazy.Builder (fromString)
 #endif
 
-#include "inline.h"
-
 -- | Convert a 'Fixed' value to a 'Builder', where the first argument indicates
 -- whether to chop off trailing zeroes.
 --
@@ -88,6 +86,7 @@ withDotB b | b == mempty = mempty
 {-# INLINE withDotB #-}
 #endif
 
+-- | /Since: 2/
 instance HasResolution a => TextShow (Fixed a) where
     showb = showbFixed False
-    INLINE_INST_FUN(showb)
+    {-# INLINE showb #-}
