@@ -4,20 +4,18 @@
 {-# OPTIONS_GHC -fno-warn-orphans #-}
 {-|
 Module:      TextShow.Data.Floating
-Copyright:   (C) 2014-2016 Ryan Scott
+Copyright:   (C) 2014-2017 Ryan Scott
 License:     BSD-style (see the file LICENSE)
 Maintainer:  Ryan Scott
 Stability:   Provisional
 Portability: GHC
 
-Monomorphic 'TextShow' functions for floating-point types.
+'TextShow' instances and monomorphic functions for floating-point types.
 
 /Since: 2/
 -}
 module TextShow.Data.Floating (
       showbRealFloatPrec
-    , showbFloatPrec
-    , showbDoublePrec
     , showbEFloat
     , showbFFloat
     , showbGFloat
@@ -41,8 +39,6 @@ import           TextShow.Classes (TextShow(..), showbParen)
 import           TextShow.TH.Internal (deriveTextShow)
 import           TextShow.Utils (i2d)
 
-#include "inline.h"
-
 -- | Convert a 'RealFloat' value to a 'Builder' with the given precedence.
 --
 -- /Since: 2/
@@ -52,19 +48,15 @@ showbRealFloatPrec p x
     | otherwise                 = showbGFloat Nothing x
 {-# INLINE showbRealFloatPrec #-}
 
--- | Convert a 'Float' to a 'Builder' with the given precedence.
---
--- /Since: 2/
-showbFloatPrec :: Int -> Float -> Builder
-showbFloatPrec = showbRealFloatPrec
-{-# INLINE showbFloatPrec #-}
-
--- | Convert a 'Double' to a 'Builder' with the given precedence.
---
--- /Since: 2/
-showbDoublePrec :: Int -> Double -> Builder
-showbDoublePrec = showbRealFloatPrec
-{-# INLINE showbDoublePrec #-}
+{-# SPECIALIZE showbEFloat ::
+        Maybe Int -> Float  -> Builder,
+        Maybe Int -> Double -> Builder #-}
+{-# SPECIALIZE showbFFloat ::
+        Maybe Int -> Float  -> Builder,
+        Maybe Int -> Double -> Builder #-}
+{-# SPECIALIZE showbGFloat ::
+        Maybe Int -> Float  -> Builder,
+        Maybe Int -> Double -> Builder #-}
 
 -- | Show a signed 'RealFloat' value
 -- using scientific (exponential) notation (e.g. @2.45e2@, @1.5e-3@).
@@ -76,7 +68,6 @@ showbDoublePrec = showbRealFloatPrec
 -- /Since: 2/
 showbEFloat :: RealFloat a => Maybe Int -> a -> Builder
 showbEFloat = formatRealFloatB Exponent
-{-# INLINE showbEFloat #-}
 
 -- | Show a signed 'RealFloat' value
 -- using standard decimal notation (e.g. @245000@, @0.0015@).
@@ -88,7 +79,6 @@ showbEFloat = formatRealFloatB Exponent
 -- /Since: 2/
 showbFFloat :: RealFloat a => Maybe Int -> a -> Builder
 showbFFloat = formatRealFloatB Fixed
-{-# INLINE showbFFloat #-}
 
 -- | Show a signed 'RealFloat' value
 -- using standard decimal notation for arguments whose absolute value lies
@@ -101,7 +91,6 @@ showbFFloat = formatRealFloatB Fixed
 -- /Since: 2/
 showbGFloat :: RealFloat a => Maybe Int -> a -> Builder
 showbGFloat = formatRealFloatB Generic
-{-# INLINE showbGFloat #-}
 
 -- | Show a signed 'RealFloat' value
 -- using standard decimal notation (e.g. @245000@, @0.0015@).
@@ -400,12 +389,15 @@ expts10 = array (minExpt,maxExpt10) [(n,10^n) | n <- [minExpt .. maxExpt10]]
 -- TextShow instances
 -------------------------------------------------------------------------------
 
+-- | /Since: 2/
 instance TextShow Float where
-    showbPrec = showbFloatPrec
-    INLINE_INST_FUN(showbPrec)
+    showbPrec = showbRealFloatPrec
+    {-# INLINE showbPrec #-}
 
+-- | /Since: 2/
 instance TextShow Double where
-    showbPrec = showbDoublePrec
-    INLINE_INST_FUN(showbPrec)
+    showbPrec = showbRealFloatPrec
+    {-# INLINE showbPrec #-}
 
+-- | /Since: 2/
 $(deriveTextShow ''FPFormat)
