@@ -3,20 +3,19 @@
 {-# OPTIONS_GHC -fno-warn-orphans #-}
 {-|
 Module:      TextShow.Data.Ratio
-Copyright:   (C) 2014-2016 Ryan Scott
+Copyright:   (C) 2014-2017 Ryan Scott
 License:     BSD-style (see the file LICENSE)
 Maintainer:  Ryan Scott
 Stability:   Provisional
 Portability: GHC
 
-Monomorphic 'TextShow' function for 'Ratio' values.
+'TextShow' instance for 'Ratio'.
 
 /Since: 2/
 -}
-module TextShow.Data.Ratio (showbRatioPrec) where
+module TextShow.Data.Ratio () where
 
 import Data.Monoid.Compat ((<>))
-import Data.Text.Lazy.Builder (Builder)
 
 import GHC.Real (Ratio(..), ratioPrec, ratioPrec1)
 
@@ -26,27 +25,10 @@ import TextShow.Classes (TextShow1(..))
 #endif
 import TextShow.Data.Integral ()
 
-#include "inline.h"
-
--- | Convert a 'Ratio' to a 'Builder' with the given precedence.
---
--- Note that on @base-4.3.0.0@, this function must have a @('Show' a, 'Integral' a)@
--- constraint instead of just a @('Show' a)@ constraint.
+-- | Note that on @base-4.3.0.0@, this must have a @('TextShow' a, 'Integral' a)@
+-- constraint instead of just a @('TextShow' a)@ constraint.
 --
 -- /Since: 2/
-showbRatioPrec ::
-#if MIN_VERSION_base(4,4,0)
-                  TextShow a
-#else
-                  (TextShow a, Integral a)
-#endif
-               => Int -> Ratio a -> Builder
-showbRatioPrec p (numer :% denom) = showbParen (p > ratioPrec) $
-       showbPrec ratioPrec1 numer
-    <> " % "
-    <> showbPrec ratioPrec1 denom
-{-# INLINE showbRatioPrec #-}
-
 instance
 #if MIN_VERSION_base(4,4,0)
          TextShow a
@@ -55,14 +37,20 @@ instance
 #endif
       => TextShow (Ratio a) where
     {-# SPECIALIZE instance TextShow Rational #-}
-    showbPrec = showbRatioPrec
-    INLINE_INST_FUN(showbPrec)
+    showbPrec p (numer :% denom) = showbParen (p > ratioPrec) $
+           showbPrec ratioPrec1 numer
+        <> " % "
+        <> showbPrec ratioPrec1 denom
+    {-# INLINE showbPrec #-}
 
 #if MIN_VERSION_base(4,4,0)
+-- | Only available with @base-4.4.0.0@ or later.
+--
+-- /Since: 2/
 instance TextShow1 Ratio where
     liftShowbPrec sp _ p (numer :% denom) = showbParen (p > ratioPrec) $
            sp ratioPrec1 numer
         <> " % "
         <> sp ratioPrec1 denom
-    INLINE_INST_FUN(liftShowbPrec)
+    {-# INLINE liftShowbPrec #-}
 #endif
