@@ -1,40 +1,32 @@
-{-# LANGUAGE CPP               #-}
 {-# LANGUAGE OverloadedStrings #-}
 {-# OPTIONS_GHC -fno-warn-orphans #-}
 {-|
 Module:      TextShow.Functions
-Copyright:   (C) 2014-2016 Ryan Scott
+Copyright:   (C) 2014-2017 Ryan Scott
 License:     BSD-style (see the file LICENSE)
 Maintainer:  Ryan Scott
 Stability:   Provisional
 Portability: GHC
 
-Optional 'TextShow', 'TextShow1', and 'TextShow2' instances for functions.
+Optional orphan 'TextShow', 'TextShow1', and 'TextShow2' instances for functions.
 
 /Since: 2/
 -}
-module TextShow.Functions (showbFunction) where
+module TextShow.Functions () where
 
-import Data.Text.Lazy.Builder (Builder)
 import TextShow.Classes (TextShow(..), TextShow1(..), TextShow2(..))
 
-#include "inline.h"
-
--- | Convert a function to a 'Builder'.
---
--- /Since: 2/
-showbFunction :: (a -> b) -> Builder
-showbFunction = showb
-{-# INLINE showbFunction #-}
-
+-- | /Since: 2/
 instance TextShow (a -> b) where
     showbPrec = liftShowbPrec undefined undefined
-    INLINE_INST_FUN(showbPrec)
+    {-# INLINE showbPrec #-}
 
+-- | /Since: 2/
 instance TextShow1 ((->) a) where
     liftShowbPrec = liftShowbPrec2 undefined undefined
-    INLINE_INST_FUN(liftShowbPrec)
+    {-# INLINE liftShowbPrec #-}
 
+-- | /Since: 2/
 instance TextShow2 (->) where
     liftShowbPrec2 _ _ _ _ _ _ = "<function>"
-    INLINE_INST_FUN(liftShowbPrec2)
+    {-# INLINE liftShowbPrec2 #-}
