@@ -4,7 +4,7 @@
 {-# LANGUAGE TemplateHaskell    #-}
 {-|
 Module:      TextShow.TH.Internal
-Copyright:   (C) 2014-2016 Ryan Scott
+Copyright:   (C) 2014-2017 Ryan Scott
 License:     BSD-style (see the file LICENSE)
 Maintainer:  Ryan Scott
 Stability:   Provisional
@@ -89,8 +89,10 @@ import           Prelude ()
 import           Prelude.Compat
 
 import           TextShow.Classes (TextShow(..), TextShow1(..), TextShow2(..),
-                                   showbListWith, showbParen, showbSpace,
-                                   showtParen, showtSpace, showtlParen, showtlSpace)
+                                   showbListWith,
+                                   showbParen,  showbCommaSpace,  showbSpace,
+                                   showtParen,  showtCommaSpace,  showtSpace,
+                                   showtlParen, showtlCommaSpace, showtlSpace)
 import           TextShow.Options (Options(..), GenTextMethods(..), defaultOptions)
 import           TextShow.Utils (isInfixDataCon, isSymVar, isTupleString)
 
@@ -599,7 +601,7 @@ makeTextShowForCon p tsClass tsFun spls (RecC conName ts) = do
                                                                      (showString argNameBase) ""
                                          in [ varE (fromStringName tsFun) `appE` stringE (infixRec ++ " = ")
                                             , makeTextShowForArg 0 tsClass tsFun conName tvMap argTy arg
-                                            , varE (fromStringName tsFun) `appE` stringE ", "
+                                            , varE (showCommaSpaceName tsFun)
                                             ]
                                    )
                                    (zip3 ts argTys args)
@@ -1379,6 +1381,11 @@ showParenName ShowbPrec  = 'showbParen
 showParenName ShowtPrec  = 'showtParen
 showParenName ShowtlPrec = 'showtlParen
 
+showCommaSpaceName :: TextShowFun -> Name
+showCommaSpaceName ShowbPrec  = 'showbCommaSpace
+showCommaSpaceName ShowtPrec  = 'showtCommaSpace
+showCommaSpaceName ShowtlPrec = 'showtlCommaSpace
+
 showSpaceName :: TextShowFun -> Name
 showSpaceName ShowbPrec  = 'showbSpace
 showSpaceName ShowtPrec  = 'showtSpace
