@@ -12,7 +12,7 @@
 
 {-|
 Module:      Derived.Records
-Copyright:   (C) 2014-2016 Ryan Scott
+Copyright:   (C) 2014-2017 Ryan Scott
 License:     BSD-style (see the file LICENSE)
 Maintainer:  Ryan Scott
 Stability:   Provisional
@@ -35,10 +35,12 @@ import           GHC.Generics (Generic1)
 # endif
 #endif
 
+import           Instances.Utils.GenericArbitrary (genericArbitrary)
+
 import           Prelude ()
 import           Prelude.Compat
 
-import           Test.QuickCheck (Arbitrary(..), oneof)
+import           Test.QuickCheck (Arbitrary(..))
 
 import           Text.Show.Deriving (deriveShow1)
 #if defined(NEW_FUNCTOR_CLASSES)
@@ -80,14 +82,12 @@ data instance TyFamily a b = TyFamilyPrefix { tf1 :: a, tf2   :: b }
 -------------------------------------------------------------------------------
 
 instance (Arbitrary a, Arbitrary b) => Arbitrary (TyCon a b) where
-    arbitrary = oneof [ TyConPrefix <$> arbitrary <*> arbitrary
-                      , (:@:)       <$> arbitrary <*> arbitrary
-                      ]
+    arbitrary = genericArbitrary
 
+#if MIN_VERSION_template_haskell(2,7,0)
 instance (Arbitrary a, Arbitrary b) => Arbitrary (TyFamily a b) where
-    arbitrary = oneof [ TyFamilyPrefix <$> arbitrary <*> arbitrary
-                      , (:!:)          <$> arbitrary <*> arbitrary
-                      ]
+    arbitrary = genericArbitrary
+#endif
 
 -------------------------------------------------------------------------------
 
