@@ -1,9 +1,17 @@
-{-# LANGUAGE CPP #-}
+{-# LANGUAGE CPP                #-}
+{-# LANGUAGE StandaloneDeriving #-}
+{-# LANGUAGE TemplateHaskell    #-}
+{-# LANGUAGE TypeFamilies       #-}
+
+#if __GLASGOW_HASKELL__ >= 702
+{-# LANGUAGE DeriveGeneric      #-}
+#endif
+
 {-# OPTIONS_GHC -fno-warn-orphans #-}
 
 {-|
 Module:      Instances.Data.Tuple
-Copyright:   (C) 2014-2016 Ryan Scott
+Copyright:   (C) 2014-2017 Ryan Scott
 License:     BSD-style (see the file LICENSE)
 Maintainer:  Ryan Scott
 Stability:   Provisional
@@ -13,10 +21,14 @@ Portability: GHC
 -}
 module Instances.Data.Tuple () where
 
-import Prelude ()
-import Prelude.Compat
-
-import Test.QuickCheck (Arbitrary(..))
+import           Data.Orphans ()
+#if __GLASGOW_HASKELL__ >= 704
+import           GHC.Generics (Generic)
+#else
+import qualified Generics.Deriving.TH as Generics (deriveAll0)
+#endif
+import           Instances.Utils.GenericArbitrary (genericArbitrary)
+import           Test.QuickCheck (Arbitrary(..))
 
 instance ( Arbitrary a
          , Arbitrary b
@@ -30,10 +42,7 @@ instance ( Arbitrary a
          , Arbitrary j
          , Arbitrary k
          ) => Arbitrary (a, b, c, d, e, f, g, h, i, j, k) where
-    arbitrary = (,,,,,,,,,,)
-        <$> arbitrary <*> arbitrary <*> arbitrary <*> arbitrary <*> arbitrary
-        <*> arbitrary <*> arbitrary <*> arbitrary <*> arbitrary <*> arbitrary
-        <*> arbitrary
+    arbitrary = genericArbitrary
 
 instance ( Arbitrary a
          , Arbitrary b
@@ -48,10 +57,7 @@ instance ( Arbitrary a
          , Arbitrary k
          , Arbitrary l
          ) => Arbitrary (a, b, c, d, e, f, g, h, i, j, k, l) where
-    arbitrary = (,,,,,,,,,,,)
-        <$> arbitrary <*> arbitrary <*> arbitrary <*> arbitrary <*> arbitrary
-        <*> arbitrary <*> arbitrary <*> arbitrary <*> arbitrary <*> arbitrary
-        <*> arbitrary <*> arbitrary
+    arbitrary = genericArbitrary
 
 instance ( Arbitrary a
          , Arbitrary b
@@ -67,10 +73,7 @@ instance ( Arbitrary a
          , Arbitrary l
          , Arbitrary m
          ) => Arbitrary (a, b, c, d, e, f, g, h, i, j, k, l, m) where
-    arbitrary = (,,,,,,,,,,,,)
-        <$> arbitrary <*> arbitrary <*> arbitrary <*> arbitrary <*> arbitrary
-        <*> arbitrary <*> arbitrary <*> arbitrary <*> arbitrary <*> arbitrary
-        <*> arbitrary <*> arbitrary <*> arbitrary
+    arbitrary = genericArbitrary
 
 instance ( Arbitrary a
          , Arbitrary b
@@ -87,10 +90,7 @@ instance ( Arbitrary a
          , Arbitrary m
          , Arbitrary n
          ) => Arbitrary (a, b, c, d, e, f, g, h, i, j, k, l, m, n) where
-    arbitrary = (,,,,,,,,,,,,,)
-        <$> arbitrary <*> arbitrary <*> arbitrary <*> arbitrary <*> arbitrary
-        <*> arbitrary <*> arbitrary <*> arbitrary <*> arbitrary <*> arbitrary
-        <*> arbitrary <*> arbitrary <*> arbitrary <*> arbitrary
+    arbitrary = genericArbitrary
 
 instance ( Arbitrary a
          , Arbitrary b
@@ -108,7 +108,18 @@ instance ( Arbitrary a
          , Arbitrary n
          , Arbitrary o
          ) => Arbitrary (a, b, c, d, e, f, g, h, i, j, k, l, m, n, o) where
-    arbitrary = (,,,,,,,,,,,,,,)
-        <$> arbitrary <*> arbitrary <*> arbitrary <*> arbitrary <*> arbitrary
-        <*> arbitrary <*> arbitrary <*> arbitrary <*> arbitrary <*> arbitrary
-        <*> arbitrary <*> arbitrary <*> arbitrary <*> arbitrary <*> arbitrary
+    arbitrary = genericArbitrary
+
+#if __GLASGOW_HASKELL__ >= 704
+deriving instance Generic (a, b, c, d, e, f, g, h, i, j, k)
+deriving instance Generic (a, b, c, d, e, f, g, h, i, j, k, l)
+deriving instance Generic (a, b, c, d, e, f, g, h, i, j, k, l, m)
+deriving instance Generic (a, b, c, d, e, f, g, h, i, j, k, l, m, n)
+deriving instance Generic (a, b, c, d, e, f, g, h, i, j, k, l, m, n, o)
+#else
+$(Generics.deriveAll0 ''(,,,,,,,,,,))
+$(Generics.deriveAll0 ''(,,,,,,,,,,,))
+$(Generics.deriveAll0 ''(,,,,,,,,,,,,))
+$(Generics.deriveAll0 ''(,,,,,,,,,,,,,))
+$(Generics.deriveAll0 ''(,,,,,,,,,,,,,,))
+#endif
