@@ -2,7 +2,7 @@
 
 {-|
 Module:      Instances.Generic
-Copyright:   (C) 2014-2016 Ryan Scott
+Copyright:   (C) 2014-2017 Ryan Scott
 License:     BSD-style (see the file LICENSE)
 Maintainer:  Ryan Scott
 Stability:   Provisional
@@ -13,13 +13,11 @@ Portability: GHC
 module Instances.Generic () where
 
 import Instances.Data.Text ()
+import Instances.Utils.GenericArbitrary (genericArbitrary)
 
-import Prelude ()
-import Prelude.Compat
-
-import Test.QuickCheck (Arbitrary(..), oneof)
+import Test.QuickCheck (Arbitrary(..))
 
 import TextShow.Generic (ConType(..))
 
 instance Arbitrary ConType where
-    arbitrary = oneof [pure Rec, pure Tup, pure Pref, Inf <$> arbitrary]
+    arbitrary = genericArbitrary
