@@ -2,7 +2,7 @@
 
 {-|
 Module:      Instances.System.Exit
-Copyright:   (C) 2014-2016 Ryan Scott
+Copyright:   (C) 2014-2017 Ryan Scott
 License:     BSD-style (see the file LICENSE)
 Maintainer:  Ryan Scott
 Stability:   Provisional
@@ -12,12 +12,11 @@ Portability: GHC
 -}
 module Instances.System.Exit () where
 
-import Prelude ()
-import Prelude.Compat
-
+import Data.Orphans ()
+import Generics.Deriving.Base ()
+import Instances.Utils.GenericArbitrary (genericArbitrary)
 import System.Exit (ExitCode(..))
-
-import Test.QuickCheck (Arbitrary(..), oneof)
+import Test.QuickCheck (Arbitrary(..))
 
 instance Arbitrary ExitCode where
-    arbitrary = oneof [pure ExitSuccess, ExitFailure <$> arbitrary]
+    arbitrary = genericArbitrary
