@@ -1,10 +1,17 @@
 {-# LANGUAGE CPP                #-}
 {-# LANGUAGE StandaloneDeriving #-}
+{-# LANGUAGE TemplateHaskell    #-}
+{-# LANGUAGE TypeFamilies       #-}
+
+#if __GLASGOW_HASKELL__ >= 702
+{-# LANGUAGE DeriveGeneric      #-}
+#endif
+
 {-# OPTIONS_GHC -fno-warn-orphans #-}
 
 {-|
 Module:      Instances.System.IO
-Copyright:   (C) 2014-2016 Ryan Scott
+Copyright:   (C) 2014-2017 Ryan Scott
 License:     BSD-style (see the file LICENSE)
 Maintainer:  Ryan Scott
 Stability:   Provisional
@@ -14,36 +21,41 @@ Portability: GHC
 -}
 module Instances.System.IO () where
 
-#if MIN_VERSION_base(4,4,0)
-import GHC.IO.Encoding.Failure (CodingFailureMode(..))
-import GHC.IO.Encoding.Types (CodingProgress(..))
+#if __GLASGOW_HASKELL__ >= 704
+import           GHC.Generics (Generic)
+#else
+import qualified Generics.Deriving.TH as Generics (deriveAll0)
 #endif
 
-import GHC.IO.Handle (HandlePosn(..))
+#if MIN_VERSION_base(4,4,0)
+import           GHC.IO.Encoding.Failure (CodingFailureMode(..))
+import           GHC.IO.Encoding.Types (CodingProgress(..))
+#endif
 
-import Prelude ()
-import Prelude.Compat
+import           GHC.IO.Handle (HandlePosn(..))
 
-import System.IO (BufferMode(..), IOMode(..), Newline(..), NewlineMode(..),
-                  SeekMode(..), Handle, stdin, stdout, stderr)
+import           Instances.Utils.GenericArbitrary (genericArbitrary)
 
-import Test.QuickCheck (Arbitrary(..), arbitraryBoundedEnum, oneof)
+import           Prelude ()
+import           Prelude.Compat
+
+import           System.IO (BufferMode(..), IOMode(..), Newline(..), NewlineMode(..),
+                            SeekMode(..), Handle, stdin, stdout, stderr)
+
+import           Test.QuickCheck (Arbitrary(..), arbitraryBoundedEnum, oneof)
 
 instance Arbitrary Handle where
     arbitrary = oneof $ map pure [stdin, stdout, stderr]
 
 instance Arbitrary HandlePosn where
-    arbitrary = HandlePosn <$> arbitrary <*> arbitrary
+    arbitrary = genericArbitrary
 
 deriving instance Bounded IOMode
 instance Arbitrary IOMode where
     arbitrary = arbitraryBoundedEnum
 
 instance Arbitrary BufferMode where
-    arbitrary = oneof [ pure NoBuffering
-                      , pure LineBuffering
-                      , BlockBuffering <$> arbitrary
-                      ]
+    arbitrary = genericArbitrary
 
 deriving instance Bounded SeekMode
 instance Arbitrary SeekMode where
@@ -67,4 +79,14 @@ instance Arbitrary Newline where
     arbitrary = arbitraryBoundedEnum
 
 instance Arbitrary NewlineMode where
-    arbitrary = NewlineMode <$> arbitrary <*> arbitrary
+    arbitrary = genericArbitrary
+
+#if __GLASGOW_HASKELL__ >= 704
+deriving instance Generic HandlePosn
+deriving instance Generic BufferMode
+deriving instance Generic NewlineMode
+#else
+$(Generics.deriveAll0 ''HandlePosn)
+$(Generics.deriveAll0 ''BufferMode)
+$(Generics.deriveAll0 ''NewlineMode)
+#endif
