@@ -6,7 +6,7 @@
 
 {-|
 Module:      Instances.System.Posix.Types
-Copyright:   (C) 2014-2016 Ryan Scott
+Copyright:   (C) 2014-2017 Ryan Scott
 License:     BSD-style (see the file LICENSE)
 Maintainer:  Ryan Scott
 Stability:   Provisional
@@ -17,6 +17,7 @@ Portability: GHC
 module Instances.System.Posix.Types () where
 
 import Instances.Foreign.C.Types ()
+import Instances.Foreign.Ptr ()
 import System.Posix.Types
 import Test.QuickCheck (Arbitrary(..))
 
@@ -123,4 +124,38 @@ instance Arbitrary CRLim where
 # endif
 #endif
 
+#if MIN_VERSION_base(4,10,0)
+# if defined(HTYPE_BLKSIZE_T)
+deriving instance Arbitrary CBlkSize
+# endif
+
+# if defined(HTYPE_BLKCNT_T)
+deriving instance Arbitrary CBlkCnt
+# endif
+
+# if defined(HTYPE_CLOCKID_T)
+deriving instance Arbitrary CClockId
+# endif
+
+# if defined(HTYPE_FSBLKCNT_T)
+deriving instance Arbitrary CFsBlkCnt
+# endif
+
+# if defined(HTYPE_FSFILCNT_T)
+deriving instance Arbitrary CFsFilCnt
+# endif
+
+# if defined(HTYPE_ID_T)
+deriving instance Arbitrary CId
+# endif
+
+# if defined(HTYPE_KEY_T)
+deriving instance Arbitrary CKey
+# endif
+
+# if defined(HTYPE_TIMER_T)
+deriving instance Arbitrary CTimer
+# endif
+#endif
+
 deriving instance Arbitrary Fd
