@@ -1,6 +1,6 @@
 {-|
-Module:      Properties.Instances
-Copyright:   (C) 2014-2016 Ryan Scott
+Module:      Instances.Utils
+Copyright:   (C) 2014-2017 Ryan Scott
 License:     BSD-style (see the file LICENSE)
 Maintainer:  Ryan Scott
 Stability:   Provisional
