@@ -2,7 +2,7 @@
 
 {-|
 Module:      Spec.Derived.DatatypeContextsSpec
-Copyright:   (C) 2014-2016 Ryan Scott
+Copyright:   (C) 2014-2017 Ryan Scott
 License:     BSD-style (see the file LICENSE)
 Maintainer:  Ryan Scott
 Stability:   Provisional
@@ -12,12 +12,10 @@ Portability: GHC
 -}
 module Spec.Derived.DatatypeContextsSpec (main, spec) where
 
+import Data.Proxy (Proxy(..))
 import Derived.DatatypeContexts
-
-import Spec.Utils (prop_matchesTextShow1)
-
+import Spec.Utils (matchesTextShow1Spec)
 import Test.Hspec (Spec, describe, hspec, parallel)
-import Test.Hspec.QuickCheck (prop)
 
 main :: IO ()
 main = hspec spec
@@ -25,8 +23,8 @@ main = hspec spec
 spec :: Spec
 spec = parallel $ do
     describe "TyCon Int Int Int" $
-        prop "TextShow1 instance" (prop_matchesTextShow1 :: Int -> TyCon Int Int Int -> Bool)
+        matchesTextShow1Spec (Proxy :: Proxy (TyCon Int Int Int))
 #if MIN_VERSION_template_haskell(2,7,0)
     describe "TyFamily Int Int Int" $
-        prop "TextShow1 instance" (prop_matchesTextShow1 :: Int -> TyFamily Int Int Int -> Bool)
+        matchesTextShow1Spec (Proxy :: Proxy (TyFamily Int Int Int))
 #endif
