@@ -2,7 +2,7 @@
 
 {-|
 Module:      Spec.GHC.EventSpec
-Copyright:   (C) 2014-2016 Ryan Scott
+Copyright:   (C) 2014-2017 Ryan Scott
 License:     BSD-style (see the file LICENSE)
 Maintainer:  Ryan Scott
 Stability:   Provisional
@@ -20,15 +20,16 @@ import Prelude.Compat
 import Test.Hspec (Spec, hspec, parallel)
 
 #if !defined(__GHCJS__) && !defined(mingw32_HOST_OS) && MIN_VERSION_base(4,4,0)
+import Data.Proxy (Proxy(..))
+
 import GHC.Event (Event)
 # if MIN_VERSION_base(4,8,1)
 import GHC.Event (Lifetime)
 #endif
 
-import Spec.Utils (prop_matchesTextShow)
+import Spec.Utils (matchesTextShowSpec)
 
 import Test.Hspec (describe)
-import Test.Hspec.QuickCheck (prop)
 #endif
 
 
@@ -39,12 +40,12 @@ spec :: Spec
 spec = parallel $ do
 #if !defined(__GHCJS__) && !defined(mingw32_HOST_OS) && MIN_VERSION_base(4,4,0)
     describe "Event" $
-        prop "TextShow instance" (prop_matchesTextShow :: Int -> Event -> Bool)
+        matchesTextShowSpec (Proxy :: Proxy Event)
 --     describe "FdKey" $
---         prop "TextShow instance" (prop_matchesTextShow :: Int -> FdKey -> Bool)
+--         matchesTextShowSpec (Proxy :: Proxy FdKey)
 # if MIN_VERSION_base(4,8,1)
     describe "Lifetime" $
-        prop "TextShow instance" (prop_matchesTextShow :: Int -> Lifetime -> Bool)
+        matchesTextShowSpec (Proxy :: Proxy Lifetime)
 # endif
 #else
     pure ()
