@@ -2,7 +2,7 @@
 
 {-|
 Module:      Spec.GHC.StackSpec
-Copyright:   (C) 2014-2016 Ryan Scott
+Copyright:   (C) 2014-2017 Ryan Scott
 License:     BSD-style (see the file LICENSE)
 Maintainer:  Ryan Scott
 Stability:   Provisional
@@ -19,13 +19,18 @@ import Prelude.Compat
 
 import Test.Hspec (Spec, hspec, parallel)
 
-#if MIN_VERSION_base(4,9,0)
-import GHC.Stack (CallStack, SrcLoc)
+#if MIN_VERSION_base(4,8,1)
+import Data.Proxy (Proxy(..))
+import GHC.Stack (CallStack)
+# if MIN_VERSION_base(4,9,0)
+import GHC.Stack (SrcLoc)
+# else
+import GHC.SrcLoc (SrcLoc)
+# endif
 
-import Spec.Utils (prop_matchesTextShow)
+import Spec.Utils (matchesTextShowSpec)
 
 import Test.Hspec (describe)
-import Test.Hspec.QuickCheck (prop)
 #endif
 
 main :: IO ()
@@ -33,11 +38,11 @@ main = hspec spec
 
 spec :: Spec
 spec = parallel $ do
-#if MIN_VERSION_base(4,9,0)
+#if MIN_VERSION_base(4,8,1)
     describe "CallStack" $
-        prop "TextShow instance" (prop_matchesTextShow :: Int -> CallStack -> Bool)
+        matchesTextShowSpec (Proxy :: Proxy CallStack)
     describe "SrcLoc" $
-        prop "TextShow instance" (prop_matchesTextShow :: Int -> SrcLoc -> Bool)
+        matchesTextShowSpec (Proxy :: Proxy SrcLoc)
 #else
     pure ()
 #endif
