@@ -1,8 +1,9 @@
-{-# LANGUAGE CPP #-}
+{-# LANGUAGE CPP             #-}
+{-# LANGUAGE TemplateHaskell #-}
 
 {-|
 Module:      Spec.Text.ReadSpec
-Copyright:   (C) 2014-2016 Ryan Scott
+Copyright:   (C) 2014-2017 Ryan Scott
 License:     BSD-style (see the file LICENSE)
 Maintainer:  Ryan Scott
 Stability:   Provisional
@@ -12,16 +13,15 @@ Portability: GHC
 -}
 module Spec.Text.ReadSpec (main, spec) where
 
+import Data.Proxy (Proxy(..))
 import Instances.Text.Read ()
-
-import Spec.Utils (prop_matchesTextShow)
-
+import Spec.Utils (matchesTextShowSpec)
 import Test.Hspec (Spec, describe, hspec, parallel)
-import Test.Hspec.QuickCheck (prop)
-
 import Text.Read (Lexeme)
-#if MIN_VERSION_base(4,7,0)
-import Text.Read.Lex (Number)
+
+#if MIN_VERSION_base(4,6,0)
+import Language.Haskell.TH.Lib (conT)
+import TextShow.TH.Names (numberTypeName)
 #endif
 
 main :: IO ()
@@ -30,8 +30,8 @@ main = hspec spec
 spec :: Spec
 spec = parallel $ do
     describe "Lexeme" $
-        prop "TextShow instance" (prop_matchesTextShow :: Int -> Lexeme -> Bool)
-#if MIN_VERSION_base(4,7,0)
+        matchesTextShowSpec (Proxy :: Proxy Lexeme)
+#if MIN_VERSION_base(4,6,0)
     describe "Number" $
-        prop "TextShow instance" (prop_matchesTextShow :: Int -> Number -> Bool)
+        matchesTextShowSpec (Proxy :: Proxy $(conT numberTypeName))
 #endif
